@@ -36,7 +36,7 @@ except:
     isHildon=False
 
 
-version="0.5"
+version="0.6"
 
 # The file header
 HEADER="#TrustMe 1"
@@ -423,22 +423,27 @@ class EditPanel(Panel):
         #label.set_alignment(0,0)
         #grid.attach(label, 0, 1, row, row+1, gtk.FILL, gtk.FILL)
 
-        #frame=gtk.Frame(" Info ")
-        #self.grid.attach(frame, 0, 3, row, row+1, gtk.FILL|gtk.EXPAND, gtk.FILL|gtk.EXPAND)
-        #frame.set_shadow_type(gtk.SHADOW_IN)
-        #frame.set_border_width(3)
+        withScroll=True
+        if withScroll:
+            #frame=gtk.Frame(" Info ")
+            #self.grid.attach(frame, 0, 3, row, row+1, gtk.FILL|gtk.EXPAND, gtk.FILL|gtk.EXPAND)
+            #frame.set_shadow_type(gtk.SHADOW_IN)
+            #frame.set_border_width(3)
         
-        #scroll=gtk.ScrolledWindow()
-        #self.grid.attach(scroll, 0, 3, row, row+1, gtk.FILL|gtk.EXPAND, gtk.FILL|gtk.EXPAND)
-        #frame.add(scroll)
-        #scroll.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-        #scroll.set_policy(gtk.POLICY_ALWAYS, gtk.POLICY_ALWAYS)
-        #scroll.set_border_width(6)
-        #if isHildon:
-        #    hildon.hildon_helper_set_thumb_scrollbar(scroll, True)
+            scroll=gtk.ScrolledWindow()
+            self.grid.attach(scroll, 0, 3, row, row+1, gtk.FILL|gtk.EXPAND, gtk.FILL|gtk.EXPAND)
+            #frame.add(scroll)
+            #scroll.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+            scroll.set_policy(gtk.POLICY_ALWAYS, gtk.POLICY_ALWAYS)
+            scroll.set_border_width(6)
+            if isHildon:
+                hildon.hildon_helper_set_thumb_scrollbar(scroll, True)
+                
         text=gtk.TextView()
-        self.grid.attach(text, 0, 3, row, row+1, gtk.FILL|gtk.EXPAND, gtk.FILL|gtk.EXPAND)
-        #scroll.add(text)
+        if not withScroll:
+            self.grid.attach(text, 0, 3, row, row+1, gtk.FILL|gtk.EXPAND, gtk.FILL|gtk.EXPAND)
+        else:
+            scroll.add(text)
         #text.set_size_request(0, 100)
         return text
 
@@ -628,7 +633,7 @@ class Main(hildon.Program):
         dialog=gtk.AboutDialog()
         dialog.set_name('TrustMe')
         dialog.set_version(version)
-        dialog.set_copyright('(C) 2009, Henning Spruth')
+        dialog.set_copyright('(C) 2009-2010, Henning Spruth')
         dialog.set_license('This program is free software and licensed under the GPL.\n\nSee /usr/share/common-licenses/GPL-2 for details.')
         dialog.set_wrap_license(True)
         dialog.set_website('http://trustme.garage.maemo.org')
